raw_init

Function raw_init 

pub unsafe fn raw_init<T>(slot: *mut T, init: impl PinInit<T>)
Initializes slot with an initializer.

Safety

  • slot is a valid pointer to uninitialized memory.
  • slot will not move until it is dropped, i.e. it will be pinned. If init implements Init<T, E>, this requirement is cancelled and it may be moved.