pub unsafe trait ZeroableOption { }Expand description
Marker trait for types that allow Option<Self> to be set to all zeroes in order to write
None to that location.
Safety
The implementer needs to ensure that unsafe impl Zeroable for Option<Self> {} is sound.
Implementations on Foreign Types
impl ZeroableOption for NonZero<i8>
impl ZeroableOption for NonZero<i16>
impl ZeroableOption for NonZero<i32>
impl ZeroableOption for NonZero<i64>
impl ZeroableOption for NonZero<i128>
impl ZeroableOption for NonZero<isize>
impl ZeroableOption for NonZero<u8>
impl ZeroableOption for NonZero<u16>
impl ZeroableOption for NonZero<u32>
impl ZeroableOption for NonZero<u64>
impl ZeroableOption for NonZero<u128>
impl ZeroableOption for NonZero<usize>
impl<T> ZeroableOption for Box<T>
impl<T, U> ZeroableOption for fn(U₁, U₂, …, Uₙ) -> T
Implemented for function pointers with up to 20 arity.
impl<T, U> ZeroableOption for extern "C" fn(U₁, U₂, …, Uₙ) -> T
Implemented for function pointers with up to 20 arity.
impl<T, U> ZeroableOption for unsafe fn(U₁, U₂, …, Uₙ) -> T
Implemented for function pointers with up to 20 arity.
impl<T, U> ZeroableOption for unsafe extern "C" fn(U₁, U₂, …, Uₙ) -> T
Implemented for function pointers with up to 20 arity.